@@ -24,7 +24,6 @@
 #include <string.h>
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <gconf/gconf-client.h>
 #include <libupower-glib/upower.h>
 
 #include "egg-debug.h"
@@ -34,7 +33,6 @@
 #include "gpm-marshal.h"
 #include "gpm-engine.h"
 #include "gpm-stock-icons.h"
-#include "gpm-prefs-server.h"
 #include "gpm-phone.h"
 
 static void     gpm_engine_finalize   (GObject	  *object);
@@ -45,13 +43,13 @@ static void     gpm_engine_finalize   (GObject	  *object);
 
 struct GpmEnginePrivate
 {
-	GConfClient		*conf;
+	GSettings		*settings;
 	UpClient		*client;
 	UpDevice		*battery_composite;
 	GPtrArray		*array;
 	GpmPhone		*phone;
 	GpmIconPolicy		 icon_policy;
-	gchar			*previous_icon;
+	GIcon			*previous_icon;
 	gchar			*previous_summary;
 
 	gboolean		 use_time_primary;
@@ -75,6 +73,7 @@ enum {
 	DISCHARGING,
 	LOW_CAPACITY,
 	PERHAPS_RECALL,
+	DEVICES_CHANGED,
 	LAST_SIGNAL
 };
 
@@ -281,7 +280,7 @@ gpm_engine_get_summary (GpmEngine *engine)
  *
  * Returns the icon
  **/
-static gchar *
+static GIcon *
 gpm_engine_get_icon_priv (GpmEngine *engine, UpDeviceKind device_kind, GpmEngineWarning warning, gboolean use_state)
 {
 	guint i;
@@ -312,15 +311,15 @@ gpm_engine_get_icon_priv (GpmEngine *engine, UpDeviceKind device_kind, GpmEngine
 		if (kind == device_kind && is_present) {
 			if (warning != GPM_ENGINE_WARNING_NONE) {
 				if (warning_temp == warning)
-					return gpm_upower_get_device_icon (device);
+					return gpm_upower_get_device_icon (device, TRUE);
 				continue;
 			}
 			if (use_state) {
 				if (state == UP_DEVICE_STATE_CHARGING || state == UP_DEVICE_STATE_DISCHARGING)
-					return gpm_upower_get_device_icon (device);
+					return gpm_upower_get_device_icon (device, TRUE);
 				continue;
 			}
-			return gpm_upower_get_device_icon (device);
+			return gpm_upower_get_device_icon (device, TRUE);
 		}
 	}
 	return NULL;
@@ -331,10 +330,10 @@ gpm_engine_get_icon_priv (GpmEngine *engine, UpDeviceKind device_kind, GpmEngine
  *
  * Returns the icon
  **/
-gchar *
+GIcon *
 gpm_engine_get_icon (GpmEngine *engine)
 {
-	gchar *icon = NULL;
+	GIcon *icon = NULL;
 
 	g_return_val_if_fail (GPM_IS_ENGINE (engine), NULL);
 
@@ -412,9 +411,8 @@ gpm_engine_get_icon (GpmEngine *engine)
 		return NULL;
 	}
 
-	/* we fallback to the ac_adapter icon */
-	egg_debug ("Using fallback");
-	return g_strdup (GPM_STOCK_AC_ADAPTER);
+	/* do not show an icon */
+	return NULL;
 }
 
 /**
@@ -423,7 +421,7 @@ gpm_engine_get_icon (GpmEngine *engine)
 static gboolean
 gpm_engine_recalculate_state_icon (GpmEngine *engine)
 {
-	gchar *icon;
+	GIcon *icon;
 
 	g_return_val_if_fail (engine != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_ENGINE (engine), FALSE);
@@ -438,31 +436,29 @@ gpm_engine_recalculate_state_icon (GpmEngine *engine)
 		egg_debug ("** EMIT: icon-changed: none");
 		g_signal_emit (engine, signals [ICON_CHANGED], 0, NULL);
 
-		g_free (engine->priv->previous_icon);
+		g_object_unref (engine->priv->previous_icon);
 		engine->priv->previous_icon = NULL;
 		return TRUE;
 	}
 
 	/* no icon before, now icon */
 	if (engine->priv->previous_icon == NULL) {
-		egg_debug ("** EMIT: icon-changed: %s", icon);
 		g_signal_emit (engine, signals [ICON_CHANGED], 0, icon);
-		engine->priv->previous_icon = icon;
+		engine->priv->previous_icon = g_object_ref (icon);
 		return TRUE;
 	}
 
 	/* icon before, now different */
-	if (strcmp (engine->priv->previous_icon, icon) != 0) {
-		g_free (engine->priv->previous_icon);
-		engine->priv->previous_icon = icon;
-		egg_debug ("** EMIT: icon-changed: %s", icon);
+	if (!g_icon_equal (engine->priv->previous_icon, icon)) {
+		g_object_unref (engine->priv->previous_icon);
+		engine->priv->previous_icon = g_object_ref (icon);
 		g_signal_emit (engine, signals [ICON_CHANGED], 0, icon);
 		return TRUE;
 	}
 
 	egg_debug ("no change");
 	/* nothing to do */
-	g_free (icon);
+	g_object_unref (icon);
 	return FALSE;
 }
 
@@ -507,33 +503,23 @@ gpm_engine_recalculate_state (GpmEngine *engine)
 
 	gpm_engine_recalculate_state_icon (engine);
 	gpm_engine_recalculate_state_summary (engine);
+
+	g_signal_emit (engine, signals [DEVICES_CHANGED], 0);
 }
 
 /**
- * gpm_engine_conf_key_changed_cb:
+ * gpm_engine_settings_key_changed_cb:
  **/
 static void
-gpm_engine_conf_key_changed_cb (GConfClient *conf, guint cnxn_id, GConfEntry *entry, GpmEngine *engine)
+gpm_engine_settings_key_changed_cb (GSettings *settings, const gchar *key, GpmEngine *engine)
 {
-	GConfValue *value;
-	gchar *icon_policy;
+	if (g_strcmp0 (key, GPM_SETTINGS_USE_TIME_POLICY) == 0) {
+		engine->priv->use_time_primary = g_settings_get_boolean (settings, key);
 
-	if (entry == NULL)
-		return;
-	value = gconf_entry_get_value (entry);
-	if (value == NULL)
-		return;
-
-	if (strcmp (entry->key, GPM_CONF_USE_TIME_POLICY) == 0) {
-
-		engine->priv->use_time_primary = gconf_value_get_bool (value);
-
-	} else if (strcmp (entry->key, GPM_CONF_UI_ICON_POLICY) == 0) {
+	} else if (g_strcmp0 (key, GPM_SETTINGS_ICON_POLICY) == 0) {
 
 		/* do we want to display the icon in the tray */
-		icon_policy = gconf_client_get_string (conf, GPM_CONF_UI_ICON_POLICY, NULL);
-		engine->priv->icon_policy = gpm_icon_policy_from_string (icon_policy);
-		g_free (icon_policy);
+		engine->priv->icon_policy = g_settings_get_enum (settings, key);
 
 		/* perhaps change icon */
 		gpm_engine_recalculate_state_icon (engine);
@@ -568,8 +554,8 @@ gpm_engine_device_check_capacity (GpmEngine *engine, UpDevice *device)
 	if (capacity < 1.0f)
 		return FALSE;
 
-	/* only emit this if specified in gconf */
-	ret = gconf_client_get_bool (engine->priv->conf, GPM_CONF_NOTIFY_LOW_CAPACITY, NULL);
+	/* only emit this if specified in the settings */
+	ret = g_settings_get_boolean (engine->priv->settings, GPM_SETTINGS_NOTIFY_LOW_CAPACITY);
 	if (ret) {
 		egg_debug ("** EMIT: low-capacity");
 		g_signal_emit (engine, signals [LOW_CAPACITY], 0, device);
@@ -587,8 +573,14 @@ gpm_engine_get_composite_device (GpmEngine *engine, UpDevice *original_device)
 	GPtrArray *array;
 	UpDevice *device;
 	UpDeviceKind kind;
+	UpDeviceKind original_kind;
 	guint i;
 
+	/* get the type of the original device */
+	g_object_get (original_device,
+		      "kind", &original_kind,
+		      NULL);
+
 	/* find out how many batteries in the system */
 	array = engine->priv->array;
 	for (i=0;i<array->len;i++) {
@@ -596,7 +588,7 @@ gpm_engine_get_composite_device (GpmEngine *engine, UpDevice *original_device)
 		g_object_get (device,
 			      "kind", &kind,
 			      NULL);
-		if (kind == UP_DEVICE_KIND_BATTERY)
+		if (kind == original_kind)
 			battery_devices++;
 	}
 
@@ -638,12 +630,18 @@ gpm_engine_update_composite_device (GpmEngine *engine, UpDevice *original_device
 	UpDevice *device;
 	UpDeviceState state;
 	UpDeviceKind kind;
+	UpDeviceKind original_kind;
 	gboolean debug;
 	gchar *text;
 
 	/* are we printing to console? */
 	debug = egg_debug_enabled ();
 
+	/* get the type of the original device */
+	g_object_get (original_device,
+		      "kind", &original_kind,
+		      NULL);
+
 	/* update the composite device */
 	array = engine->priv->array;
 	for (i=0;i<array->len;i++) {
@@ -655,7 +653,7 @@ gpm_engine_update_composite_device (GpmEngine *engine, UpDevice *original_device
 			      "energy-full", &energy_full,
 			      "energy-rate", &energy_rate,
 			      NULL);
-		if (kind != UP_DEVICE_KIND_BATTERY)
+		if (kind != original_kind)
 			continue;
 
 		if (debug) {
@@ -816,12 +814,8 @@ static gboolean
 gpm_engine_coldplug_idle_cb (GpmEngine *engine)
 {
 	guint i;
-	GPtrArray *array;
-	gboolean has_battery = FALSE;
-	gboolean has_ups = FALSE;
-	GpmPrefsServer *prefs_server;
+	GPtrArray *array = NULL;
 	UpDevice *device;
-	UpDeviceKind kind;
 	gboolean ret;
 	GError *error = NULL;
 
@@ -835,31 +829,6 @@ gpm_engine_coldplug_idle_cb (GpmEngine *engine)
 		g_error_free (error);
 		goto out;
 	}
-	engine->priv->array = up_client_get_devices (engine->priv->client);
-
-	/* do we have specific device types? */
-	array = engine->priv->array;
-	for (i=0;i<array->len;i++) {
-		device = g_ptr_array_index (engine->priv->array, i);
-
-		/* get device properties */
-		g_object_get (device,
-			      "kind", &kind,
-			      NULL);
-
-		if (kind == UP_DEVICE_KIND_BATTERY)
-			has_battery = TRUE;
-		else if (kind == UP_DEVICE_KIND_UPS)
-			has_ups = TRUE;
-	}
-
-	/* only show the battery prefs section if we have batteries */
-	prefs_server = gpm_prefs_server_new ();
-	if (has_battery)
-		gpm_prefs_server_set_capability (prefs_server, GPM_PREFS_SERVER_BATTERY);
-	if (has_ups)
-		gpm_prefs_server_set_capability (prefs_server, GPM_PREFS_SERVER_UPS);
-	g_object_unref (prefs_server);
 
 	/* connected mobile phones */
 	gpm_phone_coldplug (engine->priv->phone);
@@ -867,12 +836,15 @@ gpm_engine_coldplug_idle_cb (GpmEngine *engine)
 	gpm_engine_recalculate_state (engine);
 
 	/* add to database */
+	array = up_client_get_devices (engine->priv->client);
 	for (i=0;i<array->len;i++) {
-		device = g_ptr_array_index (engine->priv->array, i);
+		device = g_ptr_array_index (array, i);
 		gpm_engine_device_add (engine, device);
 		gpm_engine_check_recall (engine, device);
 	}
 out:
+	if (array != NULL)
+		g_ptr_array_unref (array);
 	/* never repeat */
 	return FALSE;
 }
@@ -981,6 +953,50 @@ gpm_engine_get_devices (GpmEngine *engine)
 	return g_ptr_array_ref (engine->priv->array);
 }
 
+/**
+ * gpm_engine_get_primary_device:
+ *
+ * Return value: the #UpDevice, free with g_object_unref()
+ **/
+UpDevice *
+gpm_engine_get_primary_device (GpmEngine *engine)
+{
+	guint i;
+	UpDevice *device = NULL;
+	UpDevice *device_tmp;
+	UpDeviceKind kind;
+	UpDeviceState state;
+	gboolean is_present;
+
+	for (i=0; i<engine->priv->array->len; i++) {
+		device_tmp = g_ptr_array_index (engine->priv->array, i);
+
+		/* get device properties */
+		g_object_get (device_tmp,
+			      "kind", &kind,
+			      "state", &state,
+			      "is-present", &is_present,
+			      NULL);
+
+		/* not present */
+		if (!is_present)
+			continue;
+
+		/* not discharging */
+		if (state != UP_DEVICE_STATE_DISCHARGING)
+			continue;
+
+		/* not battery */
+		if (kind != UP_DEVICE_KIND_BATTERY)
+			continue;
+
+		/* use composite device to cope with multiple batteries */
+		device = g_object_ref (gpm_engine_get_composite_device (engine, device_tmp));
+		break;
+	}
+	return device;
+}
+
 /**
  * phone_device_added_cb:
  **/
@@ -1081,7 +1097,7 @@ phone_device_refresh_cb (GpmPhone *phone, guint idx, GpmEngine *engine)
 static void
 gpm_engine_init (GpmEngine *engine)
 {
-	gchar *icon_policy;
+	guint idle_id;
 
 	engine->priv = GPM_ENGINE_GET_PRIVATE (engine);
 
@@ -1094,10 +1110,9 @@ gpm_engine_init (GpmEngine *engine)
 	g_signal_connect (engine->priv->client, "device-changed",
 			  G_CALLBACK (gpm_engine_device_changed_cb), engine);
 
-	engine->priv->conf = gconf_client_get_default ();
-	gconf_client_notify_add (engine->priv->conf, GPM_CONF_DIR,
-				 (GConfClientNotifyFunc) gpm_engine_conf_key_changed_cb,
-				 engine, NULL, NULL);
+	engine->priv->settings = g_settings_new (GPM_SETTINGS_SCHEMA);
+	g_signal_connect (engine->priv->settings, "changed",
+			  G_CALLBACK (gpm_engine_settings_key_changed_cb), engine);
 
 	engine->priv->phone = gpm_phone_new ();
 	g_signal_connect (engine->priv->phone, "device-added",
@@ -1121,28 +1136,29 @@ gpm_engine_init (GpmEngine *engine)
 	engine->priv->previous_summary = NULL;
 
 	/* do we want to display the icon in the tray */
-	icon_policy = gconf_client_get_string (engine->priv->conf, GPM_CONF_UI_ICON_POLICY, NULL);
-	engine->priv->icon_policy = gpm_icon_policy_from_string (icon_policy);
-	g_free (icon_policy);
+	engine->priv->icon_policy = g_settings_get_enum (engine->priv->settings, GPM_SETTINGS_ICON_POLICY);
 
 	/* get percentage policy */
-	engine->priv->low_percentage = gconf_client_get_int (engine->priv->conf, GPM_CONF_THRESH_PERCENTAGE_LOW, NULL);
-	engine->priv->critical_percentage = gconf_client_get_int (engine->priv->conf, GPM_CONF_THRESH_PERCENTAGE_CRITICAL, NULL);
-	engine->priv->action_percentage = gconf_client_get_int (engine->priv->conf, GPM_CONF_THRESH_PERCENTAGE_ACTION, NULL);
+	engine->priv->low_percentage = g_settings_get_int (engine->priv->settings, GPM_SETTINGS_PERCENTAGE_LOW);
+	engine->priv->critical_percentage = g_settings_get_int (engine->priv->settings, GPM_SETTINGS_PERCENTAGE_CRITICAL);
+	engine->priv->action_percentage = g_settings_get_int (engine->priv->settings, GPM_SETTINGS_PERCENTAGE_ACTION);
 
 	/* get time policy */
-	engine->priv->low_time = gconf_client_get_int (engine->priv->conf, GPM_CONF_THRESH_TIME_LOW, NULL);
-	engine->priv->critical_time = gconf_client_get_int (engine->priv->conf, GPM_CONF_THRESH_TIME_CRITICAL, NULL);
-	engine->priv->action_time = gconf_client_get_int (engine->priv->conf, GPM_CONF_THRESH_TIME_ACTION, NULL);
+	engine->priv->low_time = g_settings_get_int (engine->priv->settings, GPM_SETTINGS_TIME_LOW);
+	engine->priv->critical_time = g_settings_get_int (engine->priv->settings, GPM_SETTINGS_TIME_CRITICAL);
+	engine->priv->action_time = g_settings_get_int (engine->priv->settings, GPM_SETTINGS_TIME_ACTION);
 
 	/* we can disable this if the time remaining is inaccurate or just plain wrong */
-	engine->priv->use_time_primary = gconf_client_get_bool (engine->priv->conf, GPM_CONF_USE_TIME_POLICY, NULL);
+	engine->priv->use_time_primary = g_settings_get_boolean (engine->priv->settings, GPM_SETTINGS_USE_TIME_POLICY);
 	if (engine->priv->use_time_primary)
 		egg_debug ("Using per-time notification policy");
 	else
 		egg_debug ("Using percentage notification policy");
 
-	g_idle_add ((GSourceFunc) gpm_engine_coldplug_idle_cb, engine);
+	idle_id = g_idle_add ((GSourceFunc) gpm_engine_coldplug_idle_cb, engine);
+#if GLIB_CHECK_VERSION(2,25,8)
+	g_source_set_name_by_id (idle_id, "[GpmEngine] coldplug");
+#endif
 }
 
 /**
@@ -1161,8 +1177,8 @@ gpm_engine_class_init (GpmEngineClass *klass)
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GpmEngineClass, icon_changed),
-			      NULL, NULL, g_cclosure_marshal_VOID__STRING,
-			      G_TYPE_NONE, 1, G_TYPE_STRING);
+			      NULL, NULL, g_cclosure_marshal_VOID__OBJECT,
+			      G_TYPE_NONE, 1, G_TYPE_ICON);
 	signals [SUMMARY_CHANGED] =
 		g_signal_new ("summary-changed",
 			      G_TYPE_FROM_CLASS (object_class),
@@ -1220,6 +1236,13 @@ gpm_engine_class_init (GpmEngineClass *klass)
 			      G_STRUCT_OFFSET (GpmEngineClass, charge_critical),
 			      NULL, NULL, g_cclosure_marshal_VOID__POINTER,
 			      G_TYPE_NONE, 1, G_TYPE_POINTER);
+	signals [DEVICES_CHANGED] =
+		g_signal_new ("devices-changed",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GpmEngineClass, devices_changed),
+			      NULL, NULL, g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE, 0);
 }
 
 /**
@@ -1242,7 +1265,8 @@ gpm_engine_finalize (GObject *object)
 	g_object_unref (engine->priv->phone);
 	g_object_unref (engine->priv->battery_composite);
 
-	g_free (engine->priv->previous_icon);
+	if (engine->priv->previous_icon != NULL)
+		g_object_unref (engine->priv->previous_icon);
 	g_free (engine->priv->previous_summary);
 
 	G_OBJECT_CLASS (gpm_engine_parent_class)->finalize (object);
