@@ -38,10 +38,11 @@
 #include <gtk/gtk.h>
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
-#include <gconf/gconf-client.h>
 #include <canberra-gtk.h>
 #include <libupower-glib/upower.h>
+#ifdef HAVE_NOTIFY
 #include <libnotify/notify.h>
+#endif
 
 #include "egg-debug.h"
 #include "egg-console-kit.h"
@@ -56,7 +57,6 @@
 #include "gpm-backlight.h"
 #include "gpm-session.h"
 #include "gpm-stock-icons.h"
-#include "gpm-prefs-server.h"
 #include "gpm-tray-icon.h"
 #include "gpm-engine.h"
 #include "gpm-upower.h"
@@ -77,11 +77,10 @@ static void     gpm_manager_finalize	(GObject	 *object);
 struct GpmManagerPrivate
 {
 	GpmButton		*button;
-	GConfClient		*conf;
+	GSettings		*settings;
 	GpmDisks		*disks;
 	GpmDpms			*dpms;
 	GpmIdle			*idle;
-	GpmPrefsServer		*prefs_server;
 	GpmControl		*control;
 	GpmScreensaver		*screensaver;
 	GpmTrayIcon		*tray_icon;
@@ -200,7 +199,7 @@ gpm_manager_play_loop_start (GpmManager *manager, GpmManagerSound action, gboole
 	gint retval;
 	ca_context *context;
 
-	ret = gconf_client_get_bool (manager->priv->conf, GPM_CONF_UI_ENABLE_SOUND, NULL);
+	ret = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_ENABLE_SOUND);
 	if (!ret && !force) {
 		egg_debug ("ignoring sound due to policy");
 		return FALSE;
@@ -238,6 +237,9 @@ gpm_manager_play_loop_start (GpmManager *manager, GpmManagerSound action, gboole
 	manager->priv->critical_alert_timeout_id = g_timeout_add_seconds (timeout,
 									  (GSourceFunc) gpm_manager_play_loop_timeout_cb,
 									  manager);
+#if GLIB_CHECK_VERSION(2,25,8)
+	g_source_set_name_by_id (manager->priv->critical_alert_timeout_id, "[GpmManager] play-loop");
+#endif
 
 	/* play the sound, using sounds from the naming spec */
 	context = ca_gtk_context_get_for_screen (gdk_screen_get_default ());
@@ -261,7 +263,7 @@ gpm_manager_play (GpmManager *manager, GpmManagerSound action, gboolean force)
 	gint retval;
 	ca_context *context;
 
-	ret = gconf_client_get_bool (manager->priv->conf, GPM_CONF_UI_ENABLE_SOUND, NULL);
+	ret = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_ENABLE_SOUND);
 	if (!ret && !force) {
 		egg_debug ("ignoring sound due to policy");
 		return FALSE;
@@ -356,11 +358,11 @@ gpm_manager_sync_policy_sleep (GpmManager *manager)
 	guint sleep_computer;
 
 	if (!manager->priv->on_battery) {
-		sleep_computer = gconf_client_get_int (manager->priv->conf, GPM_CONF_TIMEOUT_SLEEP_COMPUTER_AC, NULL);
-		sleep_display = gconf_client_get_int (manager->priv->conf, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_AC, NULL);
+		sleep_computer = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SLEEP_COMPUTER_AC);
+		sleep_display = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SLEEP_DISPLAY_AC);
 	} else {
-		sleep_computer = gconf_client_get_int (manager->priv->conf, GPM_CONF_TIMEOUT_SLEEP_COMPUTER_BATT, NULL);
-		sleep_display = gconf_client_get_int (manager->priv->conf, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_BATT, NULL);
+		sleep_computer = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SLEEP_COMPUTER_BATT);
+		sleep_display = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SLEEP_DISPLAY_BATT);
 	}
 
 	/* set the new sleep (inactivity) value */
@@ -387,7 +389,7 @@ gpm_manager_blank_screen (GpmManager *manager, GError **noerror)
 	GError *error = NULL;
 
 	do_lock = gpm_control_get_lock_policy (manager->priv->control,
-					       GPM_CONF_LOCK_ON_BLANK_SCREEN);
+					       GPM_SETTINGS_LOCK_ON_BLANK_SCREEN);
 	if (do_lock) {
 		if (!gpm_screensaver_lock (manager->priv->screensaver))
 			egg_debug ("Could not lock screen via gnome-screensaver");
@@ -423,7 +425,7 @@ gpm_manager_unblank_screen (GpmManager *manager, GError **noerror)
 		ret = FALSE;
 	}
 
-	do_lock = gpm_control_get_lock_policy (manager->priv->control, GPM_CONF_LOCK_ON_BLANK_SCREEN);
+	do_lock = gpm_control_get_lock_policy (manager->priv->control, GPM_SETTINGS_LOCK_ON_BLANK_SCREEN);
 	if (do_lock)
 		gpm_screensaver_poke (manager->priv->screensaver);
 	return ret;
@@ -464,13 +466,34 @@ gpm_manager_notification_closed_cb (NotifyNotification *notification, NotifyNoti
 	*notification_class = NULL;
 }
 
+/**
+ * gpm_manager_get_icon_name:
+ **/
+static const gchar *
+gpm_manager_get_icon_name (GIcon *icon)
+{
+	const gchar* const *icon_names;
+	const gchar *icon_name = NULL;
+
+	/* no icon */
+	if (icon == NULL)
+		goto out;
+
+	/* just use the first icon */
+	icon_names = g_themed_icon_get_names (G_THEMED_ICON (icon));
+	if (icon_names != NULL)
+		icon_name = icon_names[0];
+out:
+	return icon_name;
+}
+
 /**
  * gpm_manager_notify:
  **/
 static gboolean
 gpm_manager_notify (GpmManager *manager, NotifyNotification **notification_class,
 		    const gchar *title, const gchar *message,
-		    guint timeout, const gchar *icon, NotifyUrgency urgency)
+		    guint timeout, const gchar *icon_name, NotifyUrgency urgency)
 {
 	gboolean ret;
 	GError *error = NULL;
@@ -481,11 +504,10 @@ gpm_manager_notify (GpmManager *manager, NotifyNotification **notification_class
 	gpm_manager_notify_close (manager, *notification_class);
 
 	/* if the status icon is hidden, don't point at it */
-	if (manager->priv->status_icon != NULL &&
-	    gtk_status_icon_is_embedded (manager->priv->status_icon))
-		notification = notify_notification_new_with_status_icon (title, message, icon, manager->priv->status_icon);
+	if (gtk_status_icon_is_embedded (manager->priv->status_icon))
+		notification = notify_notification_new_with_status_icon (title, message, icon_name, manager->priv->status_icon);
 	else
-		notification = notify_notification_new (title, message, icon, NULL);
+		notification = notify_notification_new (title, message, icon_name, NULL);
 	notify_notification_set_timeout (notification, timeout);
 	notify_notification_set_urgency (notification, urgency);
 	g_signal_connect (notification, "closed", G_CALLBACK (gpm_manager_notification_closed_cb), notification_class);
@@ -534,7 +556,7 @@ gpm_manager_sleep_failure_response_cb (GtkDialog *dialog, gint response_id, GpmM
 
 	/* user clicked the help button */
 	if (response_id == GTK_RESPONSE_HELP) {
-		uri = gconf_client_get_string (manager->priv->conf, GPM_CONF_NOTIFY_SLEEP_FAILED_URI, NULL);
+		uri = g_settings_get_string (manager->priv->settings, GPM_SETTINGS_NOTIFY_SLEEP_FAILED_URI);
 		screen = gdk_screen_get_default();
 		ret = gtk_show_uri (screen, uri, gtk_get_current_event_time (), &error);
 		if (!ret) {
@@ -562,8 +584,8 @@ gpm_manager_sleep_failure (GpmManager *manager, gboolean is_suspend, const gchar
 	const gchar *icon;
 	GtkWidget *dialog;
 
-	/* only show this if specified in gconf */
-	show_sleep_failed = gconf_client_get_bool (manager->priv->conf, GPM_CONF_NOTIFY_SLEEP_FAILED, NULL);
+	/* only show this if specified in settings */
+	show_sleep_failed = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_NOTIFY_SLEEP_FAILED);
 
 	egg_debug ("sleep failed");
 	gpm_manager_play (manager, GPM_MANAGER_SOUND_SUSPEND_ERROR, TRUE);
@@ -599,7 +621,7 @@ gpm_manager_sleep_failure (GpmManager *manager, gboolean is_suspend, const gchar
 	gtk_window_set_icon_name (GTK_WINDOW(dialog), icon);
 
 	/* show a button? */
-	uri = gconf_client_get_string (manager->priv->conf, GPM_CONF_NOTIFY_SLEEP_FAILED_URI, NULL);
+	uri = g_settings_get_string (manager->priv->settings, GPM_SETTINGS_NOTIFY_SLEEP_FAILED_URI);
 	if (uri != NULL && uri[0] != '\0') {
 		/* TRANSLATORS: button text, visit the suspend help website */
 		gtk_dialog_add_button (GTK_DIALOG (dialog), _("Visit help page"), GTK_RESPONSE_HELP);
@@ -665,22 +687,19 @@ gpm_manager_action_hibernate (GpmManager *manager, const gchar *reason)
  * @policy: The policy that we should do, e.g. "suspend"
  * @reason: The reason we are performing the policy action, e.g. "battery critical"
  *
- * Does one of the policy actions specified in gconf.
+ * Does one of the policy actions specified in the settings.
  **/
 static gboolean
 gpm_manager_perform_policy (GpmManager  *manager, const gchar *policy_key, const gchar *reason)
 {
-	gchar *action = NULL;
 	GpmActionPolicy policy;
 
 	/* are we inhibited? */
 	if (gpm_manager_is_inhibit_valid (manager, FALSE, "policy action") == FALSE)
 		return FALSE;
 
-	action = gconf_client_get_string (manager->priv->conf, policy_key, NULL);
-	egg_debug ("action: %s set to %s (%s)", policy_key, action, reason);
-	policy = gpm_action_policy_from_string (action);
-
+	policy = g_settings_get_enum (manager->priv->settings, policy_key);
+	egg_debug ("action: %s set to %i (%s)", policy_key, policy, reason);
 	if (policy == GPM_ACTION_POLICY_NOTHING) {
 		egg_debug ("doing nothing, reason: %s", reason);
 	} else if (policy == GPM_ACTION_POLICY_SUSPEND) {
@@ -703,44 +722,30 @@ gpm_manager_perform_policy (GpmManager  *manager, const gchar *policy_key, const
 		gpm_session_logout (session);
 		g_object_unref (session);
 	} else {
-		egg_warning ("unknown action %s", action);
+		egg_warning ("unknown action %i", policy);
 	}
 
-	g_free (action);
 	return TRUE;
 }
 
-/**
- * gpm_manager_get_preferences_options:
- **/
-gboolean
-gpm_manager_get_preferences_options (GpmManager *manager, gint *capability, GError **error)
-{
-	g_return_val_if_fail (manager != NULL, FALSE);
-	g_return_val_if_fail (GPM_IS_MANAGER (manager), FALSE);
-	return gpm_prefs_server_get_capability (manager->priv->prefs_server, capability);
-}
-
 /**
  * gpm_manager_idle_do_sleep:
  * @manager: This class instance
  *
  * This callback is called when we want to sleep. Use the users
- * preference from gconf, but change it if we can't do the action.
+ * preference from the settings, but change it if we can't do the action.
  **/
 static void
 gpm_manager_idle_do_sleep (GpmManager *manager)
 {
-	gchar *action = NULL;
 	gboolean ret;
 	GError *error = NULL;
 	GpmActionPolicy policy;
 
 	if (!manager->priv->on_battery)
-		action = gconf_client_get_string (manager->priv->conf, GPM_CONF_ACTIONS_SLEEP_TYPE_AC, NULL);
+		policy = g_settings_get_enum (manager->priv->settings, GPM_SETTINGS_ACTION_SLEEP_TYPE_AC);
 	else
-		action = gconf_client_get_string (manager->priv->conf, GPM_CONF_ACTIONS_SLEEP_TYPE_BATT, NULL);
-	policy = gpm_action_policy_from_string (action);
+		policy = g_settings_get_enum (manager->priv->settings, GPM_SETTINGS_ACTION_SLEEP_TYPE_BATT);
 
 	if (policy == GPM_ACTION_POLICY_NOTHING) {
 		egg_debug ("doing nothing as system idle action");
@@ -773,7 +778,25 @@ gpm_manager_idle_do_sleep (GpmManager *manager)
 			}
 		}
 	}
-	g_free (action);
+}
+
+/**
+ * gpm_manager_is_active:
+ **/
+static gboolean
+gpm_manager_is_active (GpmManager *manager)
+{
+	gboolean ret;
+	gboolean is_active = TRUE;
+	GError *error = NULL;
+
+	/* if we fail, assume we are on active console */
+	ret = egg_console_kit_is_active (manager->priv->console, &is_active, &error);
+	if (!ret) {
+		egg_warning ("failed to get active status: %s", error->message);
+		g_error_free (error);
+	}
+	return is_active;
 }
 
 /**
@@ -791,7 +814,7 @@ static void
 gpm_manager_idle_changed_cb (GpmIdle *idle, GpmIdleMode mode, GpmManager *manager)
 {
 	/* ConsoleKit says we are not on active console */
-	if (!egg_console_kit_is_active (manager->priv->console)) {
+	if (!gpm_manager_is_active (manager)) {
 		egg_debug ("ignoring as not on active console");
 		return;
 	}
@@ -837,14 +860,14 @@ gpm_manager_lid_button_pressed (GpmManager *manager, gboolean pressed)
 
 	if (!manager->priv->on_battery) {
 		egg_debug ("Performing AC policy");
-		gpm_manager_perform_policy (manager, GPM_CONF_BUTTON_LID_AC,
-					    "The lid has been closed on ac power.");
+		gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_LID_AC,
+					    "Lid closed on AC power.");
 		return;
 	}
 
 	egg_debug ("Performing battery policy");
-	gpm_manager_perform_policy (manager, GPM_CONF_BUTTON_LID_BATT,
-				    "The lid has been closed on battery power.");
+	gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_LID_BATT,
+				    "Lid closed on battery power.");
 }
 
 static void
@@ -920,19 +943,19 @@ gpm_manager_button_pressed_cb (GpmButton *button, const gchar *type, GpmManager
 	egg_debug ("Button press event type=%s", type);
 
 	/* ConsoleKit says we are not on active console */
-	if (!egg_console_kit_is_active (manager->priv->console)) {
+	if (!gpm_manager_is_active (manager)) {
 		egg_debug ("ignoring as not on active console");
 		return;
 	}
 
 	if (g_strcmp0 (type, GPM_BUTTON_POWER) == 0) {
-		gpm_manager_perform_policy (manager, GPM_CONF_BUTTON_POWER, "The power button has been pressed.");
+		gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_POWER, "The power button has been pressed.");
 	} else if (g_strcmp0 (type, GPM_BUTTON_SLEEP) == 0) {
-		gpm_manager_perform_policy (manager, GPM_CONF_BUTTON_SUSPEND, "The suspend button has been pressed.");
+		gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_SUSPEND, "The suspend button has been pressed.");
 	} else if (g_strcmp0 (type, GPM_BUTTON_SUSPEND) == 0) {
-		gpm_manager_perform_policy (manager, GPM_CONF_BUTTON_SUSPEND, "The suspend button has been pressed.");
+		gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_SUSPEND, "The suspend button has been pressed.");
 	} else if (g_strcmp0 (type, GPM_BUTTON_HIBERNATE) == 0) {
-		gpm_manager_perform_policy (manager, GPM_CONF_BUTTON_HIBERNATE, "The hibernate button has been pressed.");
+		gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_HIBERNATE, "The hibernate button has been pressed.");
 	} else if (g_strcmp0 (type, GPM_BUTTON_LID_OPEN) == 0) {
 		gpm_manager_lid_button_pressed (manager, FALSE);
 	} else if (g_strcmp0 (type, GPM_BUTTON_LID_CLOSED) == 0) {
@@ -971,11 +994,11 @@ gpm_manager_get_spindown_timeout (GpmManager *manager)
 
 	/* get policy */
 	if (!manager->priv->on_battery) {
-		enabled = gconf_client_get_bool (manager->priv->conf, GPM_CONF_DISKS_SPINDOWN_ENABLE_AC, NULL);
-		timeout = gconf_client_get_int (manager->priv->conf, GPM_CONF_DISKS_SPINDOWN_TIMEOUT_AC, NULL);
+		enabled = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_SPINDOWN_ENABLE_AC);
+		timeout = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SPINDOWN_TIMEOUT_AC);
 	} else {
-		enabled = gconf_client_get_bool (manager->priv->conf, GPM_CONF_DISKS_SPINDOWN_ENABLE_BATT, NULL);
-		timeout = gconf_client_get_int (manager->priv->conf, GPM_CONF_DISKS_SPINDOWN_TIMEOUT_BATT, NULL);
+		enabled = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_SPINDOWN_ENABLE_BATT);
+		timeout = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SPINDOWN_TIMEOUT_BATT);
 	}
 	if (!enabled)
 		timeout = 0;
@@ -1020,7 +1043,7 @@ gpm_manager_client_changed_cb (UpClient *client, GpmManager *manager)
 	manager->priv->on_battery = on_battery;
 
 	/* ConsoleKit says we are not on active console */
-	if (!egg_console_kit_is_active (manager->priv->console)) {
+	if (!gpm_manager_is_active (manager)) {
 		egg_debug ("ignoring as not on active console");
 		return;
 	}
@@ -1046,15 +1069,15 @@ gpm_manager_client_changed_cb (UpClient *client, GpmManager *manager)
 
 	/* We do the lid close on battery action if the ac adapter is removed
 	   when the laptop is closed and on battery. Fixes #331655 */
-	event_when_closed = gconf_client_get_bool (manager->priv->conf, GPM_CONF_ACTIONS_SLEEP_WHEN_CLOSED, NULL);
+	event_when_closed = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_SLEEP_WHEN_CLOSED);
 
 	/* We keep track of the lid state so we can do the
 	   lid close on battery action if the ac adapter is removed when the laptop
 	   is closed. Fixes #331655 */
 	if (event_when_closed && on_battery && lid_is_closed) {
-		gpm_manager_perform_policy (manager, GPM_CONF_BUTTON_LID_BATT,
+		gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_LID_BATT,
 					    "The lid has been closed, and the ac adapter "
-					    "removed (and gconf is okay).");
+					    "removed (and GSettings is okay).");
 	}
 }
 
@@ -1074,7 +1097,7 @@ manager_critical_action_do (GpmManager *manager)
 	if (manager->priv->critical_alert_timeout_id)
 		gpm_manager_play_loop_stop (manager);
 
-	gpm_manager_perform_policy (manager, GPM_CONF_ACTIONS_CRITICAL_BATT, "Battery is critically low.");
+	gpm_manager_perform_policy (manager, GPM_SETTINGS_ACTION_CRITICAL_BATT, "Battery is critically low.");
 	return FALSE;
 }
 
@@ -1091,23 +1114,17 @@ gpm_manager_class_init (GpmManagerClass *klass)
 }
 
 /**
- * gpm_conf_gconf_key_changed_cb:
+ * gpm_manager_settings_changed_cb:
  *
- * We might have to do things when the gconf keys change; do them here.
+ * We might have to do things when the keys change; do them here.
  **/
 static void
-gpm_conf_gconf_key_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, GpmManager *manager)
+gpm_manager_settings_changed_cb (GSettings *settings, const gchar *key, GpmManager *manager)
 {
-	GConfValue *value;
-
-	value = gconf_entry_get_value (entry);
-	if (value == NULL)
-		return;
-
-	if (g_strcmp0 (entry->key, GPM_CONF_TIMEOUT_SLEEP_COMPUTER_BATT) == 0 ||
-	    g_strcmp0 (entry->key, GPM_CONF_TIMEOUT_SLEEP_COMPUTER_AC) == 0 ||
-	    g_strcmp0 (entry->key, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_BATT) == 0 ||
-	    g_strcmp0 (entry->key, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_AC) == 0)
+	if (g_strcmp0 (key, GPM_SETTINGS_SLEEP_COMPUTER_BATT) == 0 ||
+	    g_strcmp0 (key, GPM_SETTINGS_SLEEP_COMPUTER_AC) == 0 ||
+	    g_strcmp0 (key, GPM_SETTINGS_SLEEP_DISPLAY_BATT) == 0 ||
+	    g_strcmp0 (key, GPM_SETTINGS_SLEEP_DISPLAY_AC) == 0)
 		gpm_manager_sync_policy_sleep (manager);
 }
 
@@ -1152,7 +1169,7 @@ gpm_manager_perhaps_recall_response_cb (GtkDialog *dialog, gint response_id, Gpm
 
 	/* don't show this again */
 	if (response_id == GTK_RESPONSE_CANCEL) {
-		gconf_client_set_bool (manager->priv->conf, GPM_CONF_NOTIFY_PERHAPS_RECALL, FALSE, NULL);
+		g_settings_set_boolean (manager->priv->settings, GPM_SETTINGS_NOTIFY_PERHAPS_RECALL, FALSE);
 		goto out;
 	}
 
@@ -1222,6 +1239,7 @@ static void
 gpm_manager_engine_perhaps_recall_cb (GpmEngine *engine, UpDevice *device, gchar *oem_vendor, gchar *website, GpmManager *manager)
 {
 	gboolean ret;
+	guint timer_id;
 
 	/* don't show when running under GDM */
 	if (g_getenv ("RUNNING_UNDER_GDM") != NULL) {
@@ -1230,9 +1248,9 @@ gpm_manager_engine_perhaps_recall_cb (GpmEngine *engine, UpDevice *device, gchar
 	}
 
 	/* already shown, and dismissed */
-	ret = gconf_client_get_bool (manager->priv->conf, GPM_CONF_NOTIFY_PERHAPS_RECALL, NULL);
+	ret = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_NOTIFY_PERHAPS_RECALL);
 	if (!ret) {
-		egg_debug ("GConf prevents notification: %s", GPM_CONF_NOTIFY_PERHAPS_RECALL);
+		egg_debug ("GConf prevents notification: %s", GPM_SETTINGS_NOTIFY_PERHAPS_RECALL);
 		return;
 	}
 
@@ -1240,14 +1258,18 @@ gpm_manager_engine_perhaps_recall_cb (GpmEngine *engine, UpDevice *device, gchar
 	g_object_set_data_full (G_OBJECT (manager), "recall-oem-website", (gpointer) g_strdup (website), (GDestroyNotify) g_free);
 
 	/* delay by a few seconds so the panel can load */
-	g_timeout_add_seconds (GPM_MANAGER_RECALL_DELAY, (GSourceFunc) gpm_manager_perhaps_recall_delay_cb, manager);
+	timer_id = g_timeout_add_seconds (GPM_MANAGER_RECALL_DELAY,
+					  (GSourceFunc) gpm_manager_perhaps_recall_delay_cb, manager);
+#if GLIB_CHECK_VERSION(2,25,8)
+	g_source_set_name_by_id (timer_id, "[GpmManager] perhaps-recall");
+#endif
 }
 
 /**
  * gpm_manager_engine_icon_changed_cb:
  */
 static void
-gpm_manager_engine_icon_changed_cb (GpmEngine  *engine, gchar *icon, GpmManager *manager)
+gpm_manager_engine_icon_changed_cb (GpmEngine  *engine, GIcon *icon, GpmManager *manager)
 {
 	gpm_tray_icon_set_icon (manager->priv->tray_icon, icon);
 }
@@ -1310,8 +1332,8 @@ gpm_manager_engine_fully_charged_cb (GpmEngine *engine, UpDevice *device, GpmMan
 	guint plural = 1;
 	const gchar *title;
 
-	/* only action this if specified in gconf */
-	ret = gconf_client_get_bool (manager->priv->conf, GPM_CONF_NOTIFY_FULLY_CHARGED, NULL);
+	/* only action this if specified in the setings */
+	ret = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_NOTIFY_FULLY_CHARGED);
 	if (!ret) {
 		egg_debug ("no notification");
 		goto out;
@@ -1361,11 +1383,11 @@ gpm_manager_engine_discharging_cb (GpmEngine *engine, UpDevice *device, GpmManag
 	gdouble percentage;
 	gint64 time_to_empty;
 	gchar *remaining_text = NULL;
-	gchar *icon = NULL;
-	const gchar *kind_desc;
+	GIcon *icon = NULL;
+	const gchar *device_desc;
 
-	/* only action this if specified in gconf */
-	ret = gconf_client_get_bool (manager->priv->conf, GPM_CONF_NOTIFY_DISCHARGING, NULL);
+	/* only action this if specified in the settings */
+	ret = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_NOTIFY_DISCHARGING);
 	if (!ret) {
 		egg_debug ("no notification");
 		goto out;
@@ -1381,7 +1403,7 @@ gpm_manager_engine_discharging_cb (GpmEngine *engine, UpDevice *device, GpmManag
 	/* only show text if there is a valid time */
 	if (time_to_empty > 0)
 		remaining_text = gpm_get_timestring (time_to_empty);
-	kind_desc = gpm_device_kind_to_localised_text (kind, 1);
+	device_desc = gpm_device_to_localised_string (device);
 
 	if (kind == UP_DEVICE_KIND_BATTERY) {
 		/* TRANSLATORS: laptop battery is now discharging */
@@ -1391,9 +1413,7 @@ gpm_manager_engine_discharging_cb (GpmEngine *engine, UpDevice *device, GpmManag
 			/* TRANSLATORS: tell the user how much time they have got */
 			message = g_strdup_printf (_("%s of battery power remaining (%.0f%%)"), remaining_text, percentage);
 		} else {
-			/* TRANSLATORS: the device is discharging, but we only have a percentage */
-			message = g_strdup_printf (_("%s discharging (%.0f%%)"),
-						   kind_desc, percentage);
+			message = g_strdup_printf ("%s (%.0f%%)", device_desc, percentage);
 		}
 	} else if (kind == UP_DEVICE_KIND_UPS) {
 		/* TRANSLATORS: UPS is now discharging */
@@ -1403,21 +1423,21 @@ gpm_manager_engine_discharging_cb (GpmEngine *engine, UpDevice *device, GpmManag
 			/* TRANSLATORS: tell the user how much time they have got */
 			message = g_strdup_printf (_("%s of UPS backup power remaining (%.0f%%)"), remaining_text, percentage);
 		} else {
-			/* TRANSLATORS: the device is discharging, but we only have a percentage */
-			message = g_strdup_printf (_("%s discharging (%.0f%%)"),
-						   kind_desc, percentage);
+			message = g_strdup (gpm_device_to_localised_string (device));
+			message = g_strdup_printf ("%s (%.0f%%)", device_desc, percentage);
 		}
 	} else {
 		/* nothing else of interest */
 		goto out;
 	}
 
-	icon = gpm_upower_get_device_icon (device);
+	icon = gpm_upower_get_device_icon (device, TRUE);
 	/* show the notification */
 	gpm_manager_notify (manager, &manager->priv->notification_discharging, title, message, GPM_MANAGER_NOTIFY_TIMEOUT_LONG,
-			    icon, NOTIFY_URGENCY_NORMAL);
+			    gpm_manager_get_icon_name (icon), NOTIFY_URGENCY_NORMAL);
 out:
-	g_free (icon);
+	if (icon != NULL)
+		g_object_unref (icon);
 	g_free (remaining_text);
 	return;
 }
@@ -1458,7 +1478,7 @@ gpm_manager_engine_charge_low_cb (GpmEngine *engine, UpDevice *device, GpmManage
 	const gchar *title = NULL;
 	gchar *message = NULL;
 	gchar *remaining_text;
-	gchar *icon = NULL;
+	GIcon *icon = NULL;
 	UpDeviceKind kind;
 	gdouble percentage;
 	gint64 time_to_empty;
@@ -1557,11 +1577,13 @@ gpm_manager_engine_charge_low_cb (GpmEngine *engine, UpDevice *device, GpmManage
 	}
 
 	/* get correct icon */
-	icon = gpm_upower_get_device_icon (device);
-	gpm_manager_notify (manager, &manager->priv->notification_warning_low, title, message, GPM_MANAGER_NOTIFY_TIMEOUT_LONG, icon, NOTIFY_URGENCY_NORMAL);
+	icon = gpm_upower_get_device_icon (device, TRUE);
+	gpm_manager_notify (manager, &manager->priv->notification_warning_low, title, message,
+			    GPM_MANAGER_NOTIFY_TIMEOUT_LONG, gpm_manager_get_icon_name (icon), NOTIFY_URGENCY_NORMAL);
 	gpm_manager_play (manager, GPM_MANAGER_SOUND_BATTERY_CAUTION, TRUE);
 out:
-	g_free (icon);
+	if (icon != NULL)
+		g_object_unref (icon);
 	g_free (message);
 }
 
@@ -1573,8 +1595,7 @@ gpm_manager_engine_charge_critical_cb (GpmEngine *engine, UpDevice *device, GpmM
 {
 	const gchar *title = NULL;
 	gchar *message = NULL;
-	gchar *action;
-	gchar *icon = NULL;
+	GIcon *icon = NULL;
 	UpDeviceKind kind;
 	gdouble percentage;
 	gint64 time_to_empty;
@@ -1609,8 +1630,7 @@ gpm_manager_engine_charge_critical_cb (GpmEngine *engine, UpDevice *device, GpmM
 		}
 
 		/* we have to do different warnings depending on the policy */
-		action = gconf_client_get_string (manager->priv->conf, GPM_CONF_ACTIONS_CRITICAL_BATT, NULL);
-		policy = gpm_action_policy_from_string (action);
+		policy = g_settings_get_enum (manager->priv->settings, GPM_SETTINGS_ACTION_CRITICAL_BATT);
 
 		/* use different text for different actions */
 		if (policy == GPM_ACTION_POLICY_NOTHING) {
@@ -1630,7 +1650,6 @@ gpm_manager_engine_charge_critical_cb (GpmEngine *engine, UpDevice *device, GpmM
 			message = g_strdup_printf (_("Computer will shutdown very soon unless it is plugged in."));
 		}
 
-		g_free (action);
 	} else if (kind == UP_DEVICE_KIND_UPS) {
 		gchar *remaining_text;
 
@@ -1711,8 +1730,9 @@ gpm_manager_engine_charge_critical_cb (GpmEngine *engine, UpDevice *device, GpmM
 	}
 
 	/* get correct icon */
-	icon = gpm_upower_get_device_icon (device);
-	gpm_manager_notify (manager, &manager->priv->notification_warning_low, title, message, GPM_MANAGER_NOTIFY_TIMEOUT_NEVER, icon, NOTIFY_URGENCY_CRITICAL);
+	icon = gpm_upower_get_device_icon (device, TRUE);
+	gpm_manager_notify (manager, &manager->priv->notification_warning_low, title, message,
+			    GPM_MANAGER_NOTIFY_TIMEOUT_NEVER, gpm_manager_get_icon_name (icon), NOTIFY_URGENCY_CRITICAL);
 
 	switch (kind) {
 
@@ -1729,7 +1749,8 @@ gpm_manager_engine_charge_critical_cb (GpmEngine *engine, UpDevice *device, GpmM
 		gpm_manager_play (manager, GPM_MANAGER_SOUND_BATTERY_LOW, TRUE);
 	}
 out:
-	g_free (icon);
+	if (icon != NULL)
+		g_object_unref (icon);
 	g_free (message);
 }
 
@@ -1740,11 +1761,11 @@ static void
 gpm_manager_engine_charge_action_cb (GpmEngine *engine, UpDevice *device, GpmManager *manager)
 {
 	const gchar *title = NULL;
-	gchar *action;
 	gchar *message = NULL;
-	gchar *icon = NULL;
+	GIcon *icon = NULL;
 	UpDeviceKind kind;
 	GpmActionPolicy policy;
+	guint timer_id;
 
 	/* get device properties */
 	g_object_get (device,
@@ -1765,8 +1786,7 @@ gpm_manager_engine_charge_action_cb (GpmEngine *engine, UpDevice *device, GpmMan
 		title = _("Laptop battery critically low");
 
 		/* we have to do different warnings depending on the policy */
-		action = gconf_client_get_string (manager->priv->conf, GPM_CONF_ACTIONS_CRITICAL_BATT, NULL);
-		policy = gpm_action_policy_from_string (action);
+		policy = g_settings_get_enum (manager->priv->settings, GPM_SETTINGS_ACTION_CRITICAL_BATT);
 
 		/* use different text for different actions */
 		if (policy == GPM_ACTION_POLICY_NOTHING) {
@@ -1793,41 +1813,42 @@ gpm_manager_engine_charge_action_cb (GpmEngine *engine, UpDevice *device, GpmMan
 					      "this computer is about to shutdown."));
 		}
 
-		g_free (action);
-
 		/* wait 20 seconds for user-panic */
-		g_timeout_add_seconds (20, (GSourceFunc) manager_critical_action_do, manager);
+		timer_id = g_timeout_add_seconds (20, (GSourceFunc) manager_critical_action_do, manager);
+#if GLIB_CHECK_VERSION(2,25,8)
+		g_source_set_name_by_id (timer_id, "[GpmManager] battery critical-action");
+#endif
 
 	} else if (kind == UP_DEVICE_KIND_UPS) {
 		/* TRANSLATORS: UPS is really, really, low */
 		title = _("UPS critically low");
 
 		/* we have to do different warnings depending on the policy */
-		action = gconf_client_get_string (manager->priv->conf, GPM_CONF_ACTIONS_CRITICAL_UPS, NULL);
-		policy = gpm_action_policy_from_string (action);
+		policy = g_settings_get_enum (manager->priv->settings, GPM_SETTINGS_ACTION_CRITICAL_UPS);
 
 		/* use different text for different actions */
 		if (policy == GPM_ACTION_POLICY_NOTHING) {
 			/* TRANSLATORS: computer will shutdown without saving data */
-			message = g_strdup (_("The UPS is below the critical level and "
+			message = g_strdup (_("UPS is below the critical level and "
 				              "this computer will <b>power-off</b> when the "
 				              "UPS becomes completely empty."));
 
 		} else if (policy == GPM_ACTION_POLICY_HIBERNATE) {
 			/* TRANSLATORS: computer will hibernate */
-			message = g_strdup (_("The UPS is below the critical level and "
+			message = g_strdup (_("UPS is below the critical level and "
 				              "this computer is about to hibernate."));
 
 		} else if (policy == GPM_ACTION_POLICY_SHUTDOWN) {
 			/* TRANSLATORS: computer will just shutdown */
-			message = g_strdup (_("The UPS is below the critical level and "
+			message = g_strdup (_("UPS is below the critical level and "
 				              "this computer is about to shutdown."));
 		}
 
 		/* wait 20 seconds for user-panic */
-		g_timeout_add_seconds (20, (GSourceFunc) manager_critical_action_do, manager);
-
-		g_free (action);
+		timer_id = g_timeout_add_seconds (20, (GSourceFunc) manager_critical_action_do, manager);
+#if GLIB_CHECK_VERSION(2,25,8)
+		g_source_set_name_by_id (timer_id, "[GpmManager] ups critical-action");
+#endif
 	}
 
 	/* not all types have actions */
@@ -1835,13 +1856,14 @@ gpm_manager_engine_charge_action_cb (GpmEngine *engine, UpDevice *device, GpmMan
 		return;
 
 	/* get correct icon */
-	icon = gpm_upower_get_device_icon (device);
+	icon = gpm_upower_get_device_icon (device, TRUE);
 	gpm_manager_notify (manager, &manager->priv->notification_warning_low,
 			    title, message, GPM_MANAGER_NOTIFY_TIMEOUT_NEVER,
-			    icon, NOTIFY_URGENCY_CRITICAL);
+			    gpm_manager_get_icon_name (icon), NOTIFY_URGENCY_CRITICAL);
 	gpm_manager_play (manager, GPM_MANAGER_SOUND_BATTERY_LOW, TRUE);
 out:
-	g_free (icon);
+	if (icon != NULL)
+		g_object_unref (icon);
 	g_free (message);
 }
 
@@ -1896,8 +1918,12 @@ gpm_manager_reset_just_resumed_cb (gpointer user_data)
 static void
 gpm_manager_control_resume_cb (GpmControl *control, GpmControlAction action, GpmManager *manager)
 {
+	guint timer_id;
 	manager->priv->just_resumed = TRUE;
-	g_timeout_add_seconds (1, gpm_manager_reset_just_resumed_cb, manager);
+	timer_id = g_timeout_add_seconds (1, gpm_manager_reset_just_resumed_cb, manager);
+#if GLIB_CHECK_VERSION(2,25,8)
+	g_source_set_name_by_id (timer_id, "[GpmManager] just-resumed");
+#endif
 }
 
 /**
@@ -1930,15 +1956,14 @@ gpm_manager_init (GpmManager *manager)
 	/* don't apply policy when not active, so listen to ConsoleKit */
 	manager->priv->console = egg_console_kit_new ();
 
-	/* this is a singleton, so we keep a master copy open here */
-	manager->priv->prefs_server = gpm_prefs_server_new ();
-
 	manager->priv->notification_general = NULL;
 	manager->priv->notification_warning_low = NULL;
 	manager->priv->notification_discharging = NULL;
 	manager->priv->notification_fully_charged = NULL;
 	manager->priv->disks = gpm_disks_new ();
-	manager->priv->conf = gconf_client_get_default ();
+	manager->priv->settings = g_settings_new (GPM_SETTINGS_SCHEMA);
+	g_signal_connect (manager->priv->settings, "changed",
+			  G_CALLBACK (gpm_manager_settings_changed_cb), manager);
 	manager->priv->client = up_client_new ();
 	g_signal_connect (manager->priv->client, "changed",
 			  G_CALLBACK (gpm_manager_client_changed_cb), manager);
@@ -1946,16 +1971,9 @@ gpm_manager_init (GpmManager *manager)
 	/* use libnotify */
 	notify_init (GPM_NAME);
 
-	/* watch gnome-power-manager keys */
-	gconf_client_add_dir (manager->priv->conf, GPM_CONF_DIR,
-			      GCONF_CLIENT_PRELOAD_RECURSIVE, NULL);
-	gconf_client_notify_add (manager->priv->conf, GPM_CONF_DIR,
-				 (GConfClientNotifyFunc) gpm_conf_gconf_key_changed_cb,
-				 manager, NULL, NULL);
-
 	/* check to see if the user has installed the schema properly */
-	version = gconf_client_get_int (manager->priv->conf, GPM_CONF_SCHEMA_VERSION, NULL);
-	if (version != GPM_CONF_SCHEMA_ID) {
+	version = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SCHEMA_VERSION);
+	if (version != GPM_SETTINGS_SCHEMA_ID) {
 		gpm_manager_notify (manager, &manager->priv->notification_general,
 				    /* TRANSLATORS: there was in install problem */
 				    _("Install problem!"),
@@ -1965,7 +1983,7 @@ gpm_manager_init (GpmManager *manager)
 				    GPM_MANAGER_NOTIFY_TIMEOUT_LONG,
 				    GTK_STOCK_DIALOG_WARNING,
 				    NOTIFY_URGENCY_NORMAL);
-		egg_error ("no gconf schema installed!");
+		egg_error ("no GSettings schema installed!");
 	}
 
 	/* coldplug so we are in the correct state at startup */
@@ -1999,7 +2017,7 @@ gpm_manager_init (GpmManager *manager)
 			  G_CALLBACK (gpm_manager_idle_changed_cb), manager);
 
 	/* set up the check_type_cpu, so we can disable the CPU load check */
-	check_type_cpu = gconf_client_get_bool (manager->priv->conf, GPM_CONF_IDLE_CHECK_CPU, NULL);
+	check_type_cpu = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_IDLE_CHECK_CPU);
 	gpm_idle_set_check_cpu (manager->priv->idle, check_type_cpu);
 
 	manager->priv->dpms = gpm_dpms_new ();
@@ -2078,14 +2096,13 @@ gpm_manager_finalize (GObject *object)
 	if (manager->priv->critical_alert_timeout_id != 0)
 		g_source_remove (manager->priv->critical_alert_timeout_id);
 
-	g_object_unref (manager->priv->conf);
+	g_object_unref (manager->priv->settings);
 	g_object_unref (manager->priv->disks);
 	g_object_unref (manager->priv->dpms);
 	g_object_unref (manager->priv->idle);
 	g_object_unref (manager->priv->engine);
 	g_object_unref (manager->priv->tray_icon);
 	g_object_unref (manager->priv->screensaver);
-	g_object_unref (manager->priv->prefs_server);
 	g_object_unref (manager->priv->control);
 	g_object_unref (manager->priv->button);
 	g_object_unref (manager->priv->backlight);
