@@ -24,14 +24,13 @@
 #include <string.h>
 #include <glib.h>
 #include <glib/gi18n.h>
+#include <gio/gio.h>
 #include <dbus/dbus-glib.h>
 
 #include "gpm-phone.h"
 #include "egg-debug.h"
 #include "gpm-marshal.h"
 
-#include "egg-dbus-monitor.h"
-
 static void     gpm_phone_finalize   (GObject	    *object);
 
 #define GPM_PHONE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_PHONE, GpmPhonePrivate))
@@ -40,7 +39,7 @@ struct GpmPhonePrivate
 {
 	DBusGProxy		*proxy;
 	DBusGConnection		*connection;
-	EggDbusMonitor		*monitor;
+	guint			 watch_id;
 	gboolean		 present;
 	guint			 percentage;
 	gboolean		 onac;	 
@@ -142,7 +141,6 @@ gpm_phone_get_num_batteries (GpmPhone *phone)
 static void
 gpm_phone_battery_state_changed (DBusGProxy *proxy, guint idx, guint percentage, gboolean on_ac, GpmPhone *phone)
 {
-	g_return_if_fail (phone != NULL);
 	g_return_if_fail (GPM_IS_PHONE (phone));
 
 	egg_debug ("got BatteryStateChanged %i = %i (%i)", idx, percentage, on_ac);
@@ -158,7 +156,6 @@ gpm_phone_battery_state_changed (DBusGProxy *proxy, guint idx, guint percentage,
 static void
 gpm_phone_num_batteries_changed (DBusGProxy *proxy, guint number, GpmPhone *phone)
 {
-	g_return_if_fail (phone != NULL);
 	g_return_if_fail (GPM_IS_PHONE (phone));
 
 	egg_debug ("got NumberBatteriesChanged %i", number);
@@ -227,15 +224,16 @@ gpm_phone_class_init (GpmPhoneClass *klass)
 }
 
 /**
- * gpm_phone_dbus_connect:
- **/
-static gboolean
-gpm_phone_dbus_connect (GpmPhone *phone)
+ * gpm_phone_service_appeared_cb:
+ */
+static void
+gpm_phone_service_appeared_cb (GDBusConnection *connection,
+			       const gchar *name, const gchar *name_owner,
+			       GpmPhone *phone)
 {
 	GError *error = NULL;
 
-	g_return_val_if_fail (phone != NULL, FALSE);
-	g_return_val_if_fail (GPM_IS_PHONE (phone), FALSE);
+	g_return_if_fail (GPM_IS_PHONE (phone));
 
 	if (phone->priv->connection == NULL) {
 		egg_debug ("get connection");
@@ -245,7 +243,7 @@ gpm_phone_dbus_connect (GpmPhone *phone)
 			egg_warning ("Could not connect to DBUS daemon: %s", error->message);
 			g_error_free (error);
 			phone->priv->connection = NULL;
-			return FALSE;
+			return;
 		}
 	}
 	if (phone->priv->proxy == NULL) {
@@ -260,7 +258,7 @@ gpm_phone_dbus_connect (GpmPhone *phone)
 			egg_warning ("Cannot connect, maybe the daemon is not running: %s", error->message);
 			g_error_free (error);
 			phone->priv->proxy = NULL;
-			return FALSE;
+			return;
 		}
 
 		/* complicated type. ick */
@@ -283,17 +281,17 @@ gpm_phone_dbus_connect (GpmPhone *phone)
 					     phone, NULL);
 
 	}
-	return TRUE;
 }
 
 /**
- * gpm_phone_dbus_disconnect:
- **/
-static gboolean
-gpm_phone_dbus_disconnect (GpmPhone *phone)
+ * gpm_phone_service_vanished_cb:
+ */
+static void
+gpm_phone_service_vanished_cb (GDBusConnection *connection,
+			        const gchar *name,
+			        GpmPhone *phone)
 {
-	g_return_val_if_fail (phone != NULL, FALSE);
-	g_return_val_if_fail (GPM_IS_PHONE (phone), FALSE);
+	g_return_if_fail (GPM_IS_PHONE (phone));
 
 	if (phone->priv->proxy != NULL) {
 		egg_debug ("removing proxy");
@@ -306,24 +304,7 @@ gpm_phone_dbus_disconnect (GpmPhone *phone)
 			g_signal_emit (phone, signals [DEVICE_REMOVED], 0, 0);
 		}
 	}
-	return TRUE;
-}
-
-/**
- * monitor_connection_cb:
- * @proxy: The dbus raw proxy
- * @status: The status of the service, where TRUE is connected
- * @screensaver: This class instance
- **/
-static void
-monitor_connection_cb (EggDbusMonitor *monitor,
-		     gboolean   status,
-		     GpmPhone  *phone)
-{
-	if (status)
-		gpm_phone_dbus_connect (phone);
-	else
-		gpm_phone_dbus_disconnect (phone);
+	return;
 }
 
 /**
@@ -333,7 +314,6 @@ monitor_connection_cb (EggDbusMonitor *monitor,
 static void
 gpm_phone_init (GpmPhone *phone)
 {
-	DBusGConnection *connection;
 	phone->priv = GPM_PHONE_GET_PRIVATE (phone);
 
 	phone->priv->connection = NULL;
@@ -342,12 +322,12 @@ gpm_phone_init (GpmPhone *phone)
 	phone->priv->percentage = 0;
 	phone->priv->onac = FALSE;
 
-	phone->priv->monitor = egg_dbus_monitor_new ();
-	g_signal_connect (phone->priv->monitor, "connection-changed",
-			  G_CALLBACK (monitor_connection_cb), phone);
-	connection = dbus_g_bus_get (DBUS_BUS_SESSION, NULL);
-	egg_dbus_monitor_assign (phone->priv->monitor, connection, GNOME_PHONE_MANAGER_DBUS_SERVICE);
-	gpm_phone_dbus_connect (phone);
+	phone->priv->watch_id = g_bus_watch_name (G_BUS_TYPE_SESSION,
+						  GNOME_PHONE_MANAGER_DBUS_SERVICE,
+						  G_BUS_NAME_WATCHER_FLAGS_NONE,
+						  (GBusNameAppearedCallback) gpm_phone_service_appeared_cb,
+						  (GBusNameVanishedCallback) gpm_phone_service_vanished_cb,
+						  phone, NULL);
 }
 
 /**
@@ -358,15 +338,14 @@ static void
 gpm_phone_finalize (GObject *object)
 {
 	GpmPhone *phone;
-	g_return_if_fail (object != NULL);
 	g_return_if_fail (GPM_IS_PHONE (object));
 
 	phone = GPM_PHONE (object);
 	phone->priv = GPM_PHONE_GET_PRIVATE (phone);
 
-	gpm_phone_dbus_disconnect (phone);
-	if (phone->priv->monitor != NULL)
-		g_object_unref (phone->priv->monitor);
+	if (phone->priv->proxy != NULL)
+		g_object_unref (phone->priv->proxy);
+	g_bus_unwatch_name (phone->priv->watch_id);
 
 	G_OBJECT_CLASS (gpm_phone_parent_class)->finalize (object);
 }
@@ -387,123 +366,3 @@ gpm_phone_new (void)
 	return GPM_PHONE (gpm_phone_object);
 }
 
-/***************************************************************************
- ***                          MAKE CHECK TESTS                           ***
- ***************************************************************************/
-#ifdef EGG_TEST
-#include "egg-test.h"
-
-static gboolean test_got_refresh = FALSE;
-
-static void
-egg_test_mainloop_wait (guint ms)
-{
-	GMainLoop *loop;
-	loop = g_main_loop_new (NULL, FALSE);
-	g_timeout_add (ms, (GSourceFunc) g_main_loop_quit, loop);
-	g_main_loop_run (loop);
-}
-
-static void
-phone_device_refresh_cb (GpmPhone *phone, guint idx, gpointer *data)
-{
-	g_debug ("idx refresh = %i", idx);
-	if (idx == 0 && GPOINTER_TO_UINT (data) == 44)
-		test_got_refresh = TRUE;
-}
-
-void
-gpm_phone_test (gpointer data)
-{
-	GpmPhone *phone;
-	guint value;
-	gboolean ret;
-	EggTest *test = (EggTest *) data;
-
-	if (egg_test_start (test, "GpmPhone") == FALSE)
-		return;
-
-	/************************************************************/
-	egg_test_title (test, "make sure we get a non null phone");
-	phone = gpm_phone_new ();
-	if (phone != NULL)
-		egg_test_success (test, "got GpmPhone");
-	else
-		egg_test_failed (test, "could not get GpmPhone");
-
-	/* connect signals */
-	g_signal_connect (phone, "device-refresh",
-			  G_CALLBACK (phone_device_refresh_cb), GUINT_TO_POINTER(44));
-
-	/************************************************************/
-	egg_test_title (test, "make sure we got a connection");
-	if (phone->priv->proxy != NULL) {
-		egg_test_success (test, "got connection");
-	} else {
-		/* skip this part of the test */
-		egg_test_success (test, "could not get a connection!");
-		goto out;
-	}
-
-	/************************************************************/
-	egg_test_title (test, "coldplug the data");
-	ret = gpm_phone_coldplug (phone);
-	if (ret) {
-		egg_test_success (test, "coldplug okay");
-	} else {
-		egg_test_failed (test, "could not coldplug");
-	}
-
-	egg_test_mainloop_wait (500);
-
-	/************************************************************/
-	egg_test_title (test, "got refresh");
-	if (test_got_refresh) {
-		egg_test_success (test, NULL);
-	} else {
-		egg_test_failed (test, "did not get refresh");
-	}
-
-	/************************************************************/
-	egg_test_title (test, "check the connected phones");
-	value = gpm_phone_get_num_batteries (phone);
-	if (value == 1) {
-		egg_test_success (test, "connected phone");
-	} else {
-		egg_test_failed (test, "not connected with %i (phone not connected?)", value);
-	}
-
-	/************************************************************/
-	egg_test_title (test, "check the present value");
-	ret = gpm_phone_get_present (phone, 0);
-	if (ret) {
-		egg_test_success (test, "we are here!");
-	} else {
-		egg_test_failed (test, "not here...");
-	}
-
-	/************************************************************/
-	egg_test_title (test, "check the percentage");
-	value = gpm_phone_get_percentage (phone, 0);
-	if (value != 0) {
-		egg_test_success (test, "percentage is %i", phone->priv->percentage);
-	} else {
-		egg_test_failed (test, "could not get value");
-	}
-
-	/************************************************************/
-	egg_test_title (test, "check the ac value");
-	ret = gpm_phone_get_on_ac (phone, 0);
-	if (!ret) {
-		egg_test_success (test, "not charging, correct");
-	} else {
-		egg_test_failed (test, "charging?");
-	}
-out:
-	g_object_unref (phone);
-
-	egg_test_end (test);
-}
-
-#endif
-
