@@ -32,10 +32,8 @@
 #include <libupower-glib/upower.h>
 
 #include "egg-debug.h"
-#include "egg-color.h"
-#include "egg-array-float.h"
-#include "egg-unique.h"
 
+#include "gpm-array-float.h"
 #include "gpm-common.h"
 #include "gpm-stock-icons.h"
 #include "gpm-upower.h"
@@ -49,7 +47,7 @@ gchar *current_device = NULL;
 static const gchar *history_type;
 static const gchar *stats_type;
 static guint history_time;
-static GConfClient *gconf_client;
+static GSettings *settings;
 static gfloat sigma_smoothing = 0.0f;
 static UpWakeups *wakeups = NULL;
 static GtkWidget *graph_history = NULL;
@@ -115,7 +113,7 @@ enum {
  * gpm_stats_button_help_cb:
  **/
 static void
-gpm_stats_button_help_cb (GtkWidget *widget, gboolean data)
+gpm_stats_button_help_cb (GtkWidget *widget, gpointer user_data)
 {
 	gpm_help_display ("statistics");
 }
@@ -156,7 +154,7 @@ gpm_stats_add_devices_columns (GtkTreeView *treeview)
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	g_object_set (renderer, "stock-size", GTK_ICON_SIZE_DIALOG, NULL);
 	column = gtk_tree_view_column_new_with_attributes (_("Image"), renderer,
-							   "icon-name", GPM_DEVICES_COLUMN_ICON, NULL);
+							   "gicon", GPM_DEVICES_COLUMN_ICON, NULL);
 	gtk_tree_view_append_column (treeview, column);
 
 	/* column for text */
@@ -236,24 +234,24 @@ gpm_stats_update_smooth_data (GPtrArray *list)
 	GpmPointObj *point;
 	GpmPointObj *point_new;
 	GPtrArray *new;
-	EggArrayFloat *raw;
-	EggArrayFloat *convolved;
-	EggArrayFloat *outliers;
-	EggArrayFloat *gaussian = NULL;
+	GpmArrayFloat *raw;
+	GpmArrayFloat *convolved;
+	GpmArrayFloat *outliers;
+	GpmArrayFloat *gaussian = NULL;
 
-	/* convert the y data to a EggArrayFloat array */
-	raw = egg_array_float_new (list->len);
+	/* convert the y data to a GpmArrayFloat array */
+	raw = gpm_array_float_new (list->len);
 	for (i=0; i<list->len; i++) {
 		point = (GpmPointObj *) g_ptr_array_index (list, i);
-		egg_array_float_set (raw, i, point->y);
+		gpm_array_float_set (raw, i, point->y);
 	}
 
 	/* remove any outliers */
-	outliers = egg_array_float_remove_outliers (raw, 3, 0.1);
+	outliers = gpm_array_float_remove_outliers (raw, 3, 0.1);
 
 	/* convolve with gaussian */
-	gaussian = egg_array_float_compute_gaussian (15, sigma_smoothing);
-	convolved = egg_array_float_convolve (outliers, gaussian);
+	gaussian = gpm_array_float_compute_gaussian (15, sigma_smoothing);
+	convolved = gpm_array_float_convolve (outliers, gaussian);
 
 	/* add the smoothed data back into a new array */
 	new = g_ptr_array_new_with_free_func ((GDestroyNotify) gpm_point_obj_free);
@@ -262,15 +260,15 @@ gpm_stats_update_smooth_data (GPtrArray *list)
 		point_new = g_new0 (GpmPointObj, 1);
 		point_new->color = point->color;
 		point_new->x = point->x;
-		point_new->y = egg_array_float_get (convolved, i);
+		point_new->y = gpm_array_float_get (convolved, i);
 		g_ptr_array_add (new, point_new);
 	}
 
 	/* free data */
-	egg_array_float_free (gaussian);
-	egg_array_float_free (raw);
-	egg_array_float_free (convolved);
-	egg_array_float_free (outliers);
+	gpm_array_float_free (gaussian);
+	gpm_array_float_free (raw);
+	gpm_array_float_free (convolved);
+	gpm_array_float_free (outliers);
 
 	return new;
 }
@@ -404,7 +402,7 @@ gpm_stats_update_info_page_details (UpDevice *device)
 	gpm_stats_add_info_data (_("Device"), device_path);
 	g_free (device_path);
 
-	gpm_stats_add_info_data (_("Type"), gpm_device_kind_to_localised_text (kind, 1));
+	gpm_stats_add_info_data (_("Type"), gpm_device_kind_to_localised_string (kind, 1));
 	if (vendor != NULL && vendor[0] != '\0')
 		gpm_stats_add_info_data (_("Vendor"), vendor);
 	if (model != NULL && model[0] != '\0')
@@ -572,7 +570,9 @@ gpm_stats_update_info_page_history (UpDevice *device)
 			      "autorange-x", FALSE,
 			      "start-x", -history_time,
 			      "stop-x", 0,
-			      "autorange-y", TRUE,
+			      "autorange-y", FALSE,
+			      "start-y", 0,
+			      "stop-y", 100,
 			      NULL);
 	} else if (g_strcmp0 (history_type, GPM_HISTORY_RATE_VALUE) == 0) {
 		g_object_set (graph_history,
@@ -621,18 +621,18 @@ gpm_stats_update_info_page_history (UpDevice *device)
 		point->x = (gint32) up_history_item_get_time (item) - offset;
 		point->y = up_history_item_get_value (item);
 		if (up_history_item_get_state (item) == UP_DEVICE_STATE_CHARGING)
-			point->color = egg_color_from_rgb (255, 0, 0);
+			point->color = gpm_color_from_rgb (255, 0, 0);
 		else if (up_history_item_get_state (item) == UP_DEVICE_STATE_DISCHARGING)
-			point->color = egg_color_from_rgb (0, 0, 255);
+			point->color = gpm_color_from_rgb (0, 0, 255);
 		else if (up_history_item_get_state (item) == UP_DEVICE_STATE_PENDING_CHARGE)
-			point->color = egg_color_from_rgb (200, 0, 0);
+			point->color = gpm_color_from_rgb (200, 0, 0);
 		else if (up_history_item_get_state (item) == UP_DEVICE_STATE_PENDING_DISCHARGE)
-			point->color = egg_color_from_rgb (0, 0, 200);
+			point->color = gpm_color_from_rgb (0, 0, 200);
 		else {
 			if (g_strcmp0 (history_type, GPM_HISTORY_RATE_VALUE) == 0)
-				point->color = egg_color_from_rgb (255, 255, 255);
+				point->color = gpm_color_from_rgb (255, 255, 255);
 			else
-				point->color = egg_color_from_rgb (0, 255, 0);
+				point->color = gpm_color_from_rgb (0, 255, 0);
 		}
 		g_ptr_array_add (new, point);
 	}
@@ -724,7 +724,7 @@ gpm_stats_update_info_page_stats (UpDevice *device)
 			point->y = up_stats_item_get_value (item);
 		else
 			point->y = up_stats_item_get_accuracy (item);
-		point->color = egg_color_from_rgb (255, 0, 0);
+		point->color = gpm_color_from_rgb (255, 0, 0);
 		g_ptr_array_add (new, point);
 	}
 
@@ -1106,7 +1106,7 @@ gpm_stats_notebook_changed_cb (GtkNotebook *notebook, gpointer page, gint page_n
 	gpm_stats_set_title (GTK_WINDOW (widget), page_num);
 
 	/* save page in gconf */
-	gconf_client_set_int (gconf_client, GPM_CONF_INFO_PAGE_NUMBER, page_num, NULL);
+	g_settings_set_int (settings, GPM_SETTINGS_INFO_PAGE_NUMBER, page_num);
 
 	if (current_device == NULL)
 		return;
@@ -1138,7 +1138,7 @@ gpm_stats_button_update_ui (void)
  * gpm_stats_devices_treeview_clicked_cb:
  **/
 static void
-gpm_stats_devices_treeview_clicked_cb (GtkTreeSelection *selection, gboolean data)
+gpm_stats_devices_treeview_clicked_cb (GtkTreeSelection *selection, gpointer user_data)
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
@@ -1150,7 +1150,7 @@ gpm_stats_devices_treeview_clicked_cb (GtkTreeSelection *selection, gboolean dat
 		gtk_tree_model_get (model, &iter, GPM_DEVICES_COLUMN_ID, &current_device, -1);
 
 		/* save device in gconf */
-		gconf_client_set_string (gconf_client, GPM_CONF_INFO_LAST_DEVICE, current_device, NULL);
+		g_settings_set_string (settings, GPM_SETTINGS_INFO_LAST_DEVICE, current_device);
 
 		/* show transaction_id */
 		egg_debug ("selected row is: %s", current_device);
@@ -1170,17 +1170,6 @@ gpm_stats_devices_treeview_clicked_cb (GtkTreeSelection *selection, gboolean dat
 	}
 }
 
-/**
- * gpm_stats_window_activated_cb
- **/
-static void
-gpm_stats_window_activated_cb (EggUnique *egg_unique, gpointer data)
-{
-	GtkWidget *widget;
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_stats"));
-	gtk_window_present (GTK_WINDOW (widget));
-}
-
 /**
  * gpm_stats_add_device:
  **/
@@ -1190,7 +1179,7 @@ gpm_stats_add_device (UpDevice *device)
 	const gchar *id;
 	GtkTreeIter iter;
 	const gchar *text;
-	const gchar *icon;
+	GIcon *icon;
 	UpDeviceKind kind;
 
 	/* get device properties */
@@ -1199,14 +1188,15 @@ gpm_stats_add_device (UpDevice *device)
 		      NULL);
 
 	id = up_device_get_object_path (device);
-	text = gpm_device_kind_to_localised_text (kind, 1);
-	icon = gpm_upower_get_device_icon (device);
+	text = gpm_device_kind_to_localised_string (kind, 1);
+	icon = gpm_upower_get_device_icon (device, FALSE);
 
 	gtk_list_store_append (list_store_devices, &iter);
 	gtk_list_store_set (list_store_devices, &iter,
 			    GPM_DEVICES_COLUMN_ID, id,
 			    GPM_DEVICES_COLUMN_TEXT, text,
 			    GPM_DEVICES_COLUMN_ICON, icon, -1);
+	g_object_unref (icon);
 }
 
 /**
@@ -1324,7 +1314,7 @@ gpm_stats_history_type_combo_changed_cb (GtkWidget *widget, gpointer data)
 	g_free (value);
 
 	/* save to gconf */
-	gconf_client_set_string (gconf_client, GPM_CONF_INFO_HISTORY_TYPE, history_type, NULL);
+	g_settings_set_string (settings, GPM_SETTINGS_INFO_HISTORY_TYPE, history_type);
 }
 
 /**
@@ -1375,7 +1365,7 @@ gpm_stats_type_combo_changed_cb (GtkWidget *widget, gpointer data)
 	g_free (value);
 
 	/* save to gconf */
-	gconf_client_set_string (gconf_client, GPM_CONF_INFO_STATS_TYPE, stats_type, NULL);
+	g_settings_set_string (settings, GPM_SETTINGS_INFO_STATS_TYPE, stats_type);
 }
 
 /**
@@ -1400,7 +1390,7 @@ gpm_stats_range_combo_changed (GtkWidget *widget, gpointer data)
 		g_assert (FALSE);
 
 	/* save to gconf */
-	gconf_client_set_int (gconf_client, GPM_CONF_INFO_HISTORY_TIME, history_time, NULL);
+	g_settings_set_int (settings, GPM_SETTINGS_INFO_HISTORY_TIME, history_time);
 
 	gpm_stats_button_update_ui ();
 	g_free (value);
@@ -1415,7 +1405,7 @@ gpm_stats_smooth_checkbox_history_cb (GtkWidget *widget, gpointer data)
 {
 	gboolean checked;
 	checked = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-	gconf_client_set_bool (gconf_client, GPM_CONF_INFO_HISTORY_GRAPH_SMOOTH, checked, NULL);
+	g_settings_set_boolean (settings, GPM_SETTINGS_INFO_HISTORY_GRAPH_SMOOTH, checked);
 	gpm_stats_button_update_ui ();
 }
 
@@ -1428,7 +1418,7 @@ gpm_stats_smooth_checkbox_stats_cb (GtkWidget *widget, gpointer data)
 {
 	gboolean checked;
 	checked = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-	gconf_client_set_bool (gconf_client, GPM_CONF_INFO_STATS_GRAPH_SMOOTH, checked, NULL);
+	g_settings_set_boolean (settings, GPM_SETTINGS_INFO_STATS_GRAPH_SMOOTH, checked);
 	gpm_stats_button_update_ui ();
 }
 
@@ -1441,7 +1431,7 @@ gpm_stats_points_checkbox_history_cb (GtkWidget *widget, gpointer data)
 {
 	gboolean checked;
 	checked = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-	gconf_client_set_bool (gconf_client, GPM_CONF_INFO_HISTORY_GRAPH_POINTS, checked, NULL);
+	g_settings_set_boolean (settings, GPM_SETTINGS_INFO_HISTORY_GRAPH_POINTS, checked);
 	gpm_stats_button_update_ui ();
 }
 
@@ -1454,7 +1444,7 @@ gpm_stats_points_checkbox_stats_cb (GtkWidget *widget, gpointer data)
 {
 	gboolean checked;
 	checked = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-	gconf_client_set_bool (gconf_client, GPM_CONF_INFO_STATS_GRAPH_POINTS, checked, NULL);
+	g_settings_set_boolean (settings, GPM_SETTINGS_INFO_STATS_GRAPH_POINTS, checked);
 	gpm_stats_button_update_ui ();
 }
 
@@ -1515,6 +1505,25 @@ gpm_stats_highlight_device (const gchar *object_path)
 	}
 }
 
+/**
+ * gpm_stats_delete_event_cb:
+ **/
+static gboolean
+gpm_stats_delete_event_cb (GtkWidget *widget, GdkEvent *event, GtkApplication *application)
+{
+	gtk_application_quit (application);
+	return FALSE;
+}
+
+/**
+ * gpm_stats_button_close_cb:
+ **/
+static void
+gpm_stats_button_close_cb (GtkWidget *widget, GtkApplication *application)
+{
+	gtk_application_quit (application);
+}
+
 /**
  * main:
  **/
@@ -1526,7 +1535,7 @@ main (int argc, char *argv[])
 	GtkBox *box;
 	GtkWidget *widget;
 	GtkTreeSelection *selection;
-	EggUnique *egg_unique;
+	GtkApplication *application;
 	gboolean ret;
 	UpClient *client;
 	GPtrArray *devices;
@@ -1571,19 +1580,14 @@ main (int argc, char *argv[])
 	gtk_init (&argc, &argv);
 
 	/* are we already activated? */
-	egg_unique = egg_unique_new ();
-	ret = egg_unique_assign (egg_unique, "org.gnome.PowerManager.Statistics");
-	if (!ret)
-		goto unique_out;
-	g_signal_connect (egg_unique, "activated",
-			  G_CALLBACK (gpm_stats_window_activated_cb), NULL);
+	application = gtk_application_new ("org.gnome.PowerManager.Statistics", &argc, &argv);
 
 	/* add application specific icons to search path */
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
                                            GPM_DATA G_DIR_SEPARATOR_S "icons");
 
 	/* get data from gconf */
-	gconf_client = gconf_client_get_default ();
+	settings = g_settings_new (GPM_SETTINGS_SCHEMA);
 
 	/* get UI */
 	builder = gtk_builder_new ();
@@ -1608,14 +1612,17 @@ main (int argc, char *argv[])
 	gtk_widget_show (graph_statistics);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_stats"));
+	gtk_application_add_window (application, GTK_WINDOW (widget));
 	gtk_window_set_default_size (GTK_WINDOW(widget), 800, 500);
 	gtk_window_set_default_icon_name (GPM_STOCK_APP_ICON);
 
 	/* Get the main window quit */
-	g_signal_connect_swapped (widget, "delete_event", G_CALLBACK (gtk_main_quit), NULL);
+	g_signal_connect (widget, "delete-event",
+			  G_CALLBACK (gpm_stats_delete_event_cb), application);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_close"));
-	g_signal_connect_swapped (widget, "clicked", G_CALLBACK (gtk_main_quit), NULL);
+	g_signal_connect (widget, "clicked",
+			  G_CALLBACK (gpm_stats_button_close_cb), application);
 	gtk_widget_grab_default (widget);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_help"));
@@ -1623,38 +1630,38 @@ main (int argc, char *argv[])
 			  G_CALLBACK (gpm_stats_button_help_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_smooth_history"));
-	checked = gconf_client_get_bool (gconf_client, GPM_CONF_INFO_HISTORY_GRAPH_SMOOTH, NULL);
+	checked = g_settings_get_boolean (settings, GPM_SETTINGS_INFO_HISTORY_GRAPH_SMOOTH);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), checked);
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (gpm_stats_smooth_checkbox_history_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_smooth_stats"));
-	checked = gconf_client_get_bool (gconf_client, GPM_CONF_INFO_STATS_GRAPH_SMOOTH, NULL);
+	checked = g_settings_get_boolean (settings, GPM_SETTINGS_INFO_STATS_GRAPH_SMOOTH);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), checked);
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (gpm_stats_smooth_checkbox_stats_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_points_history"));
-	checked = gconf_client_get_bool (gconf_client, GPM_CONF_INFO_HISTORY_GRAPH_POINTS, NULL);
+	checked = g_settings_get_boolean (settings, GPM_SETTINGS_INFO_HISTORY_GRAPH_POINTS);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), checked);
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (gpm_stats_points_checkbox_history_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_points_stats"));
-	checked = gconf_client_get_bool (gconf_client, GPM_CONF_INFO_STATS_GRAPH_POINTS, NULL);
+	checked = g_settings_get_boolean (settings, GPM_SETTINGS_INFO_STATS_GRAPH_POINTS);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), checked);
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (gpm_stats_points_checkbox_stats_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "notebook1"));
-	page = gconf_client_get_int (gconf_client, GPM_CONF_INFO_PAGE_NUMBER, NULL);
+	page = g_settings_get_int (settings, GPM_SETTINGS_INFO_PAGE_NUMBER);
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), page);
 	g_signal_connect (widget, "switch-page",
 			  G_CALLBACK (gpm_stats_notebook_changed_cb), NULL);
 
 	/* create list stores */
 	list_store_info = gtk_list_store_new (GPM_INFO_COLUMN_LAST, G_TYPE_STRING, G_TYPE_STRING);
-	list_store_devices = gtk_list_store_new (GPM_DEVICES_COLUMN_LAST, G_TYPE_STRING,
+	list_store_devices = gtk_list_store_new (GPM_DEVICES_COLUMN_LAST, G_TYPE_ICON,
 						 G_TYPE_STRING, G_TYPE_STRING);
 	list_store_wakeups = gtk_list_store_new (GPM_WAKEUPS_COLUMN_LAST, G_TYPE_STRING,
 						 G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
@@ -1689,14 +1696,14 @@ main (int argc, char *argv[])
 	gpm_stats_add_wakeups_columns (GTK_TREE_VIEW (widget));
 	gtk_tree_view_columns_autosize (GTK_TREE_VIEW (widget)); /* show */
 
-	history_type = gconf_client_get_string (gconf_client, GPM_CONF_INFO_HISTORY_TYPE, NULL);
-	history_time = gconf_client_get_int (gconf_client, GPM_CONF_INFO_HISTORY_TIME, NULL);
+	history_type = g_settings_get_string (settings, GPM_SETTINGS_INFO_HISTORY_TYPE);
+	history_time = g_settings_get_int (settings, GPM_SETTINGS_INFO_HISTORY_TIME);
 	if (history_type == NULL)
 		history_type = GPM_HISTORY_CHARGE_VALUE;
 	if (history_time == 0)
 		history_time = GPM_HISTORY_HOUR_VALUE;
 
-	stats_type = gconf_client_get_string (gconf_client, GPM_CONF_INFO_STATS_TYPE, NULL);
+	stats_type = g_settings_get_string (settings, GPM_SETTINGS_INFO_STATS_TYPE);
 	if (stats_type == NULL)
 		stats_type = GPM_STATS_CHARGE_DATA_VALUE;
 
@@ -1749,19 +1756,19 @@ main (int argc, char *argv[])
 	g_signal_connect (G_OBJECT (widget), "changed",
 			  G_CALLBACK (gpm_stats_range_combo_changed), NULL);
 
-	client = up_client_new ();
-	g_signal_connect (client, "device-added", G_CALLBACK (gpm_stats_device_added_cb), NULL);
-	g_signal_connect (client, "device-removed", G_CALLBACK (gpm_stats_device_removed_cb), NULL);
-	g_signal_connect (client, "device-changed", G_CALLBACK (gpm_stats_device_changed_cb), NULL);
 
 	wakeups = up_wakeups_new ();
 	g_signal_connect (wakeups, "data-changed", G_CALLBACK (gpm_stats_data_changed_cb), NULL);
 
 	/* coldplug */
+	client = up_client_new ();
 	ret = up_client_enumerate_devices_sync (client, NULL, NULL);
 	if (!ret)
 		goto out;
 	devices = up_client_get_devices (client);
+	g_signal_connect (client, "device-added", G_CALLBACK (gpm_stats_device_added_cb), NULL);
+	g_signal_connect (client, "device-removed", G_CALLBACK (gpm_stats_device_removed_cb), NULL);
+	g_signal_connect (client, "device-changed", G_CALLBACK (gpm_stats_device_changed_cb), NULL);
 
 	/* add devices in visually pleasing order */
 	for (j=0; j<UP_DEVICE_KIND_LAST; j++) {
@@ -1781,18 +1788,21 @@ main (int argc, char *argv[])
 	}
 
 	if (last_device == NULL)
-		last_device = gconf_client_get_string (gconf_client, GPM_CONF_INFO_LAST_DEVICE, NULL);
+		last_device = g_settings_get_string (settings, GPM_SETTINGS_INFO_LAST_DEVICE);
 
 	/* has capability to measure wakeups */
 	ret = up_wakeups_get_has_capability (wakeups);
 	if (ret) {
 		GtkTreeIter iter;
+		GIcon *icon;
+		icon = g_themed_icon_new ("computer");
 		gtk_list_store_append (list_store_devices, &iter);
 		gtk_list_store_set (list_store_devices, &iter,
 				    GPM_DEVICES_COLUMN_ID, "wakeups",
 				    /* TRANSLATORS: the icon for the CPU */
 				    GPM_DEVICES_COLUMN_TEXT, _("Processor"),
-				    GPM_DEVICES_COLUMN_ICON, "computer", -1);
+				    GPM_DEVICES_COLUMN_ICON, icon, -1);
+		g_object_unref (icon);
 	}
 
 	/* set the correct focus on the last device */
@@ -1810,16 +1820,16 @@ main (int argc, char *argv[])
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_stats"));
 	gtk_widget_show (widget);
 
-	gtk_main ();
+	/* run */
+	gtk_application_run (application);
 
 out:
-	g_object_unref (gconf_client);
+	g_object_unref (settings);
 	g_object_unref (client);
 	g_object_unref (wakeups);
 	g_object_unref (builder);
 	g_object_unref (list_store_info);
-unique_out:
-	g_object_unref (egg_unique);
+	g_object_unref (application);
 	g_free (last_device);
 	return 0;
 }
